getAllCubesList: Get list of all available data tables

Description Usage Value Examples

View source: R/cube-series-metadata.R

Description

Users can query the output database to provide a complete inventory of data tables available through this Statistics Canada API. This command accesses a comprehensive list of details about each table including information at the dimension level.

Usage

1

Value

An httr response object

Examples

1
2
3
4
## Not run: 
getAllCubesList()

## End(Not run)

tweed1e/statcanopener documentation built on Jan. 19, 2021, 4:23 p.m.