getCubeMetadata: Get cube/table metadata

Description Usage Arguments Value Examples

View source: R/cube-series-metadata.R

Description

Get cube/table titles, product ID, CANSIM ID, release date, and more.

Usage

1
getCubeMetadata(productId)

Arguments

productId

Product Identification number (PID) is a unique product identifier for all Statistics Canada products, including large multidimensional tables. The first two digits refer to a subject, the next two digits refer to product type, the last four digits refer to the product itself.

Value

An httr response object

Examples

1
2
3
4
## Not run: 
getCubeMetadata(35100003)

## End(Not run)

tweed1e/statcanopener documentation built on Jan. 19, 2021, 4:23 p.m.