Description Usage Arguments Value Examples
View source: R/cube-series-metadata.R
Get cube/table titles, product ID, CANSIM ID, release date, and more.
1 | getCubeMetadata(productId)
|
productId |
Product Identification number (PID) is a unique product identifier for all Statistics Canada products, including large multidimensional tables. The first two digits refer to a subject, the next two digits refer to product type, the last four digits refer to the product itself. |
An httr response object
1 2 3 4 | ## Not run:
getCubeMetadata(35100003)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.